@@ -35,14 +35,14 @@
 #include <tqstringlist.h>
 
 // KDE includes
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kiconloader.h>
 #include <klineedit.h>
 #include <kcombobox.h>
 #include <kdebug.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <dcopclient.h>
 
 #ifdef __FreeBSD__
@@ -111,14 +111,14 @@ void Smb4KPasswordHandler::open_close_wallet()
       // error handling here.
       if ( kapp )
       {
-        (void) kapp->kdeinitExec( "kwalletmanager" );
+        (void) kapp->tdeinitExec( "tdewalletmanager" );
       }
       else
       {
         // Do nothing. --- Good luck!
       }
 
-      m_wallet = KWallet::Wallet::openWallet( KWallet::Wallet::NetworkWallet(), 0, KWallet::Wallet::Synchronous );
+      m_wallet = TDEWallet::Wallet::openWallet( TDEWallet::Wallet::NetworkWallet(), 0, TDEWallet::Wallet::Synchronous );
 
       if ( m_wallet )
       {
@@ -136,7 +136,7 @@ void Smb4KPasswordHandler::open_close_wallet()
       }
       else
       {
-        Smb4KError::error( ERROR_OPENING_WALLET_FAILED, KWallet::Wallet::NetworkWallet(), TQString() );
+        Smb4KError::error( ERROR_OPENING_WALLET_FAILED, TDEWallet::Wallet::NetworkWallet(), TQString() );
 
         delete m_wallet;
         m_wallet = NULL;
@@ -783,17 +783,17 @@ void Smb4KPasswordHandler::writeToSMBConfFile( Smb4KAuthInfo *authInfo )
 {
   m_nsmbrc_auth = *authInfo;
 
-  KProcess *p = new KProcess();
+  TDEProcess *p = new TDEProcess();
   p->setUseShell( true );
 
-  connect( p,    TQT_SIGNAL( receivedStdout( KProcess *, char *, int ) ),
-           this, TQT_SLOT( slotReceivePassword( KProcess *, char *, int ) ) );
-  connect( p,    TQT_SIGNAL( processExited( KProcess * ) ),
-           this, TQT_SLOT( slotWritePassword( KProcess * ) ) );
+  connect( p,    TQT_SIGNAL( receivedStdout( TDEProcess *, char *, int ) ),
+           this, TQT_SLOT( slotReceivePassword( TDEProcess *, char *, int ) ) );
+  connect( p,    TQT_SIGNAL( processExited( TDEProcess * ) ),
+           this, TQT_SLOT( slotWritePassword( TDEProcess * ) ) );
 
   *p << TQString( "smbutil crypt %1" ).arg( m_nsmbrc_auth.password() );
 
-  p->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+  p->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput );
 }
 
 #endif
@@ -831,17 +831,17 @@ void Smb4KPasswordHandler::slotEnableOKButton( const TQString &text )
 }
 
 #ifdef __FreeBSD__
-void Smb4KPasswordHandler::slotReceivePassword( KProcess *, char *buffer, int buflen )
+void Smb4KPasswordHandler::slotReceivePassword( TDEProcess *, char *buffer, int buflen )
 {
   m_buffer.append( TQString::fromLocal8Bit( buffer, buflen ) );
 #else
-void Smb4KPasswordHandler::slotReceivePassword( KProcess *, char *, int )
+void Smb4KPasswordHandler::slotReceivePassword( TDEProcess *, char *, int )
 {
 #endif
 }
 
 
-void Smb4KPasswordHandler::slotWritePassword( KProcess *proc )
+void Smb4KPasswordHandler::slotWritePassword( TDEProcess *proc )
 {
 
   delete proc;
