@@ -28,17 +28,17 @@
 #include <tqheader.h>
 
 // KDE includes
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <kstdaction.h>
-#include <klocale.h>
-#include <kaboutdata.h>
-#include <klocale.h>
-#include <kaction.h>
-#include <kshortcut.h>
+#include <tdelocale.h>
+#include <tdeaboutdata.h>
+#include <tdelocale.h>
+#include <tdeaction.h>
+#include <tdeshortcut.h>
 #include <kdebug.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kiconloader.h>
-#include <kactionclasses.h>
+#include <tdeactionclasses.h>
 
 // application specific includes
 #include "smb4kshareslistview_part.h"
@@ -50,8 +50,8 @@
 #include "../core/smb4ksettings.h"
 
 
-KInstance *Smb4KSharesListViewPartFactory::m_instance = 0L;
-KAboutData *Smb4KSharesListViewPartFactory::m_about = 0L;
+TDEInstance *Smb4KSharesListViewPartFactory::m_instance = 0L;
+TDEAboutData *Smb4KSharesListViewPartFactory::m_about = 0L;
 
 
 Smb4KSharesListViewPart::Smb4KSharesListViewPart( TQWidget *parentWidget, const char *widgetName,
@@ -108,24 +108,24 @@ Smb4KSharesListViewPart::~Smb4KSharesListViewPart()
 void Smb4KSharesListViewPart::setupActions()
 {
   // Create the actions:
-  KAction *unmount =   new KAction( i18n( "&Unmount" ), "hdd_unmount", KShortcut( CTRL+Key_U ),
+  TDEAction *unmount =   new TDEAction( i18n( "&Unmount" ), "drive-harddisk", TDEShortcut( CTRL+Key_U ),
                                     this, TQT_SLOT( slotUnmountShare() ),
                                     actionCollection(), "unmount_action" );
 #ifdef __linux__
-  KAction *force =     new KAction( i18n( "&Force Unmounting" ), "hdd_unmount", KShortcut( CTRL+Key_F ),
+  TDEAction *force =     new TDEAction( i18n( "&Force Unmounting" ), "drive-harddisk", TDEShortcut( CTRL+Key_F ),
                                     this, TQT_SLOT( slotForceUnmountShare() ),
                                     actionCollection(), "force_unmount_action" );
 #endif
-  KAction *all =       new KAction( i18n( "U&nmount All" ), "gear", KShortcut( CTRL+Key_N ),
+  TDEAction *all =       new TDEAction( i18n( "U&nmount All" ), "gear", TDEShortcut( CTRL+Key_N ),
                                     this, TQT_SLOT( slotUnmountAllShares() ),
                                     actionCollection(), "unmount_all_action" );
-  KAction *sync =      new KAction( i18n( "S&ynchronize" ), "bottom", KShortcut( CTRL+Key_Y ),
+  TDEAction *sync =      new TDEAction( i18n( "S&ynchronize" ), "go-bottom", TDEShortcut( CTRL+Key_Y ),
                                     this, TQT_SLOT( slotSynchronize() ),
                                     actionCollection(), "synchronize_action" );
-  KAction *konsole =   new KAction( i18n( "Open with Konso&le" ), "terminal", KShortcut( CTRL+Key_L ),
+  TDEAction *konsole =   new TDEAction( i18n( "Open with Konso&le" ), "terminal", TDEShortcut( CTRL+Key_L ),
                                     this, TQT_SLOT( slotKonsole() ),
                                     actionCollection(), "konsole_action" );
-  KAction *konq =      new KAction( i18n( "Open with &Konqueror" ), "kfm_home", KShortcut( CTRL+Key_K ),
+  TDEAction *konq =      new TDEAction( i18n( "Open with &Konqueror" ), "kfm_home", TDEShortcut( CTRL+Key_K ),
                                     this, TQT_SLOT( slotFilemanager() ),
                                     actionCollection(), "filemanager_action" );
 
@@ -140,8 +140,8 @@ void Smb4KSharesListViewPart::setupActions()
   konq->setEnabled( false );
 
   // Insert the actions into the menu:
-  m_menu = new KActionMenu( this, "SharesListViewMenu" );
-  m_menu->popupMenu()->insertTitle( SmallIcon( "hdd_mount" ), i18n( "Shares" ), 0 );
+  m_menu = new TDEActionMenu( this, "SharesListViewMenu" );
+  m_menu->popupMenu()->insertTitle( SmallIcon( "drive-harddisk-mounted" ), i18n( "Shares" ), 0 );
   m_menu->insert( unmount, -1 );
 #ifdef __linux__
   m_menu->insert( force, -1 );
@@ -307,7 +307,7 @@ void Smb4KSharesListViewPart::customEvent( TQCustomEvent *e )
     }
     case EVENT_SET_FOCUS:
     {
-      KListView *view = static_cast<KListView *>( m_widget );
+      TDEListView *view = static_cast<TDEListView *>( m_widget );
 
       if ( view->childCount() != 0 )
       {
@@ -338,12 +338,12 @@ void Smb4KSharesListViewPart::slotContextMenuRequested( TQListViewItem *item, co
 {
   if ( item )
   {
-    m_menu->popupMenu()->changeTitle( 0, SmallIcon( "hdd_mount" ),
+    m_menu->popupMenu()->changeTitle( 0, SmallIcon( "drive-harddisk-mounted" ),
                                       static_cast<Smb4KSharesListViewItem *>( item )->shareObject()->name() );
   }
   else
   {
-    m_menu->popupMenu()->changeTitle( 0, SmallIcon( "hdd_mount" ), i18n( "Shares" ) );
+    m_menu->popupMenu()->changeTitle( 0, SmallIcon( "drive-harddisk-mounted" ), i18n( "Shares" ) );
   }
 
   m_menu->popupMenu()->exec( pos, 0 );
@@ -352,7 +352,7 @@ void Smb4KSharesListViewPart::slotContextMenuRequested( TQListViewItem *item, co
 
 void Smb4KSharesListViewPart::slotSelectionChanged( TQListViewItem *item )
 {
-  // NOTE: Here we only enable or disable the KActions. All other things
+  // NOTE: Here we only enable or disable the TDEActions. All other things
   // are done in the Smb4KSharesListView class.
 
   // This slot is used to enable or disable the actions when the user
@@ -391,7 +391,7 @@ void Smb4KSharesListViewPart::slotSelectionChanged( TQListViewItem *item )
 
 void Smb4KSharesListViewPart::slotMouseButtonPressed( TQListViewItem *item )
 {
-  // NOTE: Here we only enable or disable the KActions. All other things
+  // NOTE: Here we only enable or disable the TDEActions. All other things
   // are done in the Smb4KSharesListView class.
 
   // Here we do all the stuff that cannot be done in
@@ -669,14 +669,14 @@ TQObject *parent, const char *name, const char *, const TQStringList & )
 }
 
 
-KInstance *Smb4KSharesListViewPartFactory::instance()
+TDEInstance *Smb4KSharesListViewPartFactory::instance()
 {
   if( !m_instance )
   {
-    m_about = new KAboutData( "smb4kshareslistviewpart", I18N_NOOP( "Smb4KSharesListViewPart" ), "1.0" );
+    m_about = new TDEAboutData( "smb4kshareslistviewpart", I18N_NOOP( "Smb4KSharesListViewPart" ), "1.0" );
     m_about->addAuthor("Alexander Reinholdt", 0, "dustpuppy@users.berlios.de");
-    m_about->setLicense( KAboutData::License_GPL );
-    m_instance = new KInstance( m_about );
+    m_about->setLicense( TDEAboutData::License_GPL );
+    m_instance = new TDEInstance( m_about );
   }
 
   return m_instance;
@@ -691,7 +691,7 @@ extern "C"
 {
   void *init_libsmb4kshareslistview()
   {
-    KGlobal::locale()->insertCatalogue( "smb4k" );
+    TDEGlobal::locale()->insertCatalogue( "smb4k" );
     return new Smb4KSharesListViewPartFactory;
   }
 }
